@@ -2,7 +2,7 @@
 from datetime import datetime, date, time, tzinfo, timezone, timedelta
 from itertools import product
 
-from idebug import *
+from ipylib.idebug import *
 
 
 __all__ = [
