@@ -1,8 +1,6 @@
 
-
 import re
-import pandas as pd
-from pandas.io.json import json_normalize
+
 
 
 def set_difference(li1, li2):
