@@ -2,7 +2,7 @@
 import os
 from pathlib import PureWindowsPath, PurePosixPath
 
-from idebug import *
+from ipylib.idebug import *
 
 
 __all__ = [
